@@ -1,9 +1,7 @@
 """
     domonic.dom
     ~~~~~~~~~
-
     methods on the dom
-
 """
 
 from typing import *
@@ -99,12 +97,12 @@ class Node(EventTarget):
         # self.args = args
         # self.kwargs = kwargs
         self.baseURI = 'eventual.technology'
-        self.baseURIObject = None
-        self.isConnected = None
-        self.localName = None
-        self.namespaceURI = None
+        # self.baseURIObject = None
+        self.isConnected = True
+        # self.localName = None
+        self.namespaceURI = "http://www.w3.org/1999/xhtml"
         self.nextSibling = None
-        self.nodePrincipal = None
+        # self.nodePrincipal = None
         self.outerText = None
         self.ownerDocument = None
         self.parentElement = None
@@ -158,6 +156,10 @@ class Node(EventTarget):
         # pass
         return 1
 
+    @property
+    def localName(self):
+        return self.tagName
+
     @property
     def nodeName(self):
         ''' Returns the name of a node'''
@@ -263,13 +265,25 @@ class Element(Node):
         ''' Returns a List of an element's attributes'''
         return self.attributes
 
-    def innerHTML(self, *args) -> str:
+    @property
+    def innerHTML(self) -> str:
         ''' Sets or returns the content of an element'''
-        self.content = ''.join([each.__str__() for each in args])
+        # self.args = args
         return self.content
 
-    def html(self, *args) -> str: 
-        return self.innerHTML(*args)  # jquery
+    @innerHTML.setter
+    def innerHTML(self, value):
+        
+        if value is not None:
+            self.args = (value,)  # TODO - will need the parser to work for this to work properly. for now shove all on first content node
+        
+        return self.content
+
+
+    def html(self, *args) -> str : 
+        self.args = args
+        return self
+
 
     def blur(self):
         '''Removes focus from an element'''
@@ -410,10 +424,6 @@ class Element(Node):
         else:
             return False
 
-    # def hasChildNodes(self):
-        '''Returns true if an element has any child nodes, otherwise false'''
-        # return len(self.args)>1
-
     @property
     def id(self):
         ''' Sets or returns the value of the id attribute of an element'''
